django-rest-resources
=====================

A simple REST framework for Django, with support for choosing
alternate representations based on RFC 2616 Accept, Accept-Language, and
Content-Type headers.

MIT Licensed.
